@@ -1,8 +1,8 @@
 package List::Compare::Base::_Auxiliary;
-$VERSION = 0.52;
+our $VERSION = 0.54;
 use Carp;
-@ISA = qw(Exporter);
-@EXPORT_OK = qw|
+our @ISA = qw(Exporter);
+our @EXPORT_OK = qw|
     _validate_2_seenhashes
     _validate_seen_hash
     _validate_multiple_seenhashes
@@ -39,7 +39,7 @@ use Carp;
     _alt_construct_tester_4
     _alt_construct_tester_5
 |;
-%EXPORT_TAGS = (
+our %EXPORT_TAGS = (
     calculate => [ qw(
         _calculate_array_seen_only
         _calculate_seen_only
@@ -73,8 +73,7 @@ my $bad_lists_msg = q{If argument is single hash ref, you must have a 'lists' ke
 
 sub _validate_2_seenhashes {
     my ($refL, $refR) = @_;
-    my (%seenL, %seenR);
-    my (%badentriesL, %badentriesR);
+    my (%seenL, %seenR, %badentriesL, %badentriesR);
     foreach (keys %$refL) {
         if (${$refL}{$_} =~ /^\d+$/ and ${$refL}{$_} > 0) {
             $seenL{$_} = ${$refL}{$_};
@@ -259,21 +258,44 @@ sub _calculate_sharedref {
     return $sharedref;
 }
 
+sub _is_list_subset {
+    my ( $subset, $superset ) = @_;
+    # return false if the superset value is false
+    # for any subset value.
+    # note that this does *not* validate overlap of
+    # the keys; it validates the truth of supserset
+    # values.
+    $superset->{ $_ } or return 0 for keys %$subset;
+    return 1;
+}
+
 sub _subset_subengine {
     my $aref = shift;
     my (@xsubset);
     my %seen = %{_calculate_seen_only($aref)};
     foreach my $i (keys %seen) {
         foreach my $j (keys %seen) {
-            $xsubset[$i][$j] = 1;
-            foreach my $k (keys %{$seen{$i}}) {
-                $xsubset[$i][$j] = 0 if (! $seen{$j}{$k});
+            if ( $i eq $j ) {
+                $xsubset[$i][$j] = 1;
+            }
+            elsif ( $i gt $j ) {
+                if ( scalar(keys %{ $seen{$i} }) == scalar(keys %{ $seen{$j} }) ){
+                    $xsubset[$i][$j] = _is_list_subset($seen{$i}, $seen{$j});
+                    $xsubset[$j][$i] = $xsubset[$i][$j];
+                }
+                elsif ( scalar(keys %{ $seen{$i} }) < scalar(keys %{ $seen{$j} }) ){
+                    $xsubset[$i][$j] = _is_list_subset($seen{$i}, $seen{$j});
+                    $xsubset[$j][$i] = 0;
+                }
+                else {
+                    $xsubset[$j][$i] = _is_list_subset($seen{$j}, $seen{$i});
+                    $xsubset[$i][$j] = 0;
+                }
             }
         }
     }
     return \@xsubset;
 }
-
 sub _chart_engine_regular {
     my $aref = shift;
     my @sub_or_eqv = @$aref;
@@ -526,7 +548,7 @@ sub _argument_checker_4 {
         if (@{$args[1]} == 2) {
             my $last_index = $#{$args[0]};
             foreach my $i (@{$args[1]}) {
-		        croak "No element in index position $i in list of list references passed as first argument to function: $!"
+                croak "No element in index position $i in list of list references passed as first argument to function: $!"
                     unless ($i =~ /^\d+$/ and $i <= $last_index);
             }
             return (_argument_checker($args[0]), $args[1]);
@@ -694,8 +716,8 @@ List::Compare::Base::_Auxiliary - Internal use only
 
 =head1 VERSION
 
-This document refers to version 0.52 of List::Compare::Base::_Auxiliary.
-This version was released May 21 2015.
+This document refers to version 0.54 of List::Compare::Base::_Auxiliary.
+This version was released August 16 2020.
 
 =head1 SYNOPSIS
 
@@ -707,8 +729,8 @@ List::Compare::Functional.  They are not intended to be publicly callable.
 James E. Keenan (jkeenan@cpan.org).  When sending correspondence, please
 include 'List::Compare' or 'List-Compare' in your subject line.
 
-Creation date:  May 20, 2002.  Last modification date:  February 25 2015.
-Copyright (c) 2002-15 James E. Keenan.  United States.  All rights reserved.
+Creation date:  May 20, 2002.  Last modification date:  February 25 2020.
+Copyright (c) 2002-20 James E. Keenan.  United States.  All rights reserved.
 This is free software and may be distributed under the same terms as Perl
 itself.
 
